"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.transform = transform;
exports.getScaledRect = getScaledRect;

/**
 * 获取旋转指定角度后的rect
 * @param  {[type]} options rect
 * @param  {[type]} angle   旋转角度
 * @return {[type]}
 */
function transform(options, angle) {
  var x = options.x;
  var y = options.y;
  var width = options.width;
  var height = options.height;
  console.log('options', options, angle);
  var r = Math.sqrt(Math.pow(width, 2) + Math.pow(height, 2)) / 2;
  var a = Math.round(Math.atan(height / width) * 180 / Math.PI);
  var tlbra = 180 - angle - a;
  var trbla = a - angle;
  var ta = 90 - angle;
  var ra = angle;
  var halfWidth = width / 2;
  var halfHeight = height / 2;
  var middleX = x + halfWidth;
  var middleY = y + halfHeight;
  var topLeft = {
    x: middleX + r * Math.cos(tlbra * Math.PI / 180),
    y: middleY - r * Math.sin(tlbra * Math.PI / 180)
  };
  var top = {
    x: middleX + halfHeight * Math.cos(ta * Math.PI / 180),
    y: middleY - halfHeight * Math.sin(ta * Math.PI / 180)
  };
  var topRight = {
    x: middleX + r * Math.cos(trbla * Math.PI / 180),
    y: middleY - r * Math.sin(trbla * Math.PI / 180)
  };
  var right = {
    x: middleX + halfWidth * Math.cos(ra * Math.PI / 180),
    y: middleY + halfWidth * Math.sin(ra * Math.PI / 180)
  };
  var bottomRight = {
    x: middleX - r * Math.cos(tlbra * Math.PI / 180),
    y: middleY + r * Math.sin(tlbra * Math.PI / 180)
  };
  var bottom = {
    x: middleX - halfHeight * Math.sin(ra * Math.PI / 180),
    y: middleY + halfHeight * Math.cos(ra * Math.PI / 180)
  };
  var bottomLeft = {
    x: middleX - r * Math.cos(trbla * Math.PI / 180),
    y: middleY + r * Math.sin(trbla * Math.PI / 180)
  };
  var left = {
    x: middleX - halfWidth * Math.cos(ra * Math.PI / 180),
    y: middleY - halfWidth * Math.sin(ra * Math.PI / 180)
  };
  var minX = Math.min(topLeft.x, topRight.x, bottomRight.x, bottomLeft.x);
  var maxX = Math.max(topLeft.x, topRight.x, bottomRight.x, bottomLeft.x);
  var minY = Math.min(topLeft.y, topRight.y, bottomRight.y, bottomLeft.y);
  var maxY = Math.max(topLeft.y, topRight.y, bottomRight.y, bottomLeft.y);
  return {
    point: [topLeft, top, topRight, right, bottomRight, bottom, bottomLeft, left],
    width: maxX - minX,
    height: maxY - minY,
    left: minX,
    right: maxX,
    top: minY,
    bottom: maxY
  };
}
/**
 * 取得缩放指定倍数后的坐标
 * @param  {[type]} isEqualRatio    是否等比
 * @param  {[type]} params    rect
 * @param  {[type]} baseIndex 基点索引
 */


function getScaledRect(isEqualRatio, params, baseIndex) {
  var x = params.x,
      y = params.y,
      width = params.width,
      height = params.height,
      scale = params.scale;
  var offset = {
    x: 0,
    y: 0
  }; // const ratio = width / height;

  var deltaXScale = scale.x - 1; // 增加比例

  var deltaYScale = scale.y - 1; // var deltaYScale = deltaXScale; // 是否缩放在此控制
  // console.log('deltaXScale', deltaXScale);
  // console.log('deltaYScale', deltaYScale);
  // console.log('deltaYScale', ratio, params, scale.x, scale.y);
  // deltaXScale=0 或者 deltaYScale=0 表示不是4个顶点

  if (isEqualRatio && (deltaXScale === 0 || deltaYScale === 0) && deltaXScale !== deltaYScale) {
    if (deltaXScale === 0) deltaXScale = deltaYScale; // 宽度增加多少，高度等比增加多少

    if (deltaYScale === 0) deltaYScale = deltaXScale;
  }

  var deltaWidth = width * deltaXScale;
  var deltaHeight = height * deltaYScale;
  var newWidth = width + deltaWidth;
  var newHeight = height + deltaHeight;
  var newX = x - deltaWidth / 2;
  var newY = y - deltaHeight / 2;

  if (baseIndex) {
    var points = [{
      x: x,
      y: y
    }, {
      x: x + width,
      y: y
    }, {
      x: x + width,
      y: y + height
    }, {
      x: x,
      y: y + height
    }];
    var newPoints = [{
      x: newX,
      y: newY
    }, {
      x: newX + newWidth,
      y: newY
    }, {
      x: newX + newWidth,
      y: newY + newHeight
    }, {
      x: newX,
      y: newY + newHeight
    }];
    offset.x = points[baseIndex].x - newPoints[baseIndex].x;
    offset.y = points[baseIndex].y - newPoints[baseIndex].y;
  }

  return {
    x: newX + offset.x,
    y: newY + offset.y,
    width: newWidth,
    height: newHeight
  };
}